@@ -19,6 +19,8 @@
 #'   be one of `"pointwise"` or `"boot"` for pointwise confidence bands, or
 #'   `"ks"` or `"ts"` for simultaneous testing. See `qqplotr::stat_qq_band()`
 #'   for details.
+#' @param base_size,size_axis_title,size_title Numeric value specifying size of
+#' axis and plot titles.
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
 #'
@@ -42,6 +44,9 @@ plot.see_check_normality <- function(x,
                                      data = NULL,
                                      size_line = 0.8,
                                      size_point = 2,
+                                     size_title = 12,
+                                     size_axis_title = base_size,
+                                     base_size = 10,
                                      alpha = 0.2,
                                      dot_alpha = 0.8,
                                      colors = c("#3aaf85", "#1b6ca8"),
@@ -67,7 +72,10 @@ plot.see_check_normality <- function(x,
       attributes(x)$re_qq,
       size_point = size_point,
       size_line = size_line,
-      alpha_level = alpha
+      alpha_level = alpha,
+      size_axis_title = size_axis_title,
+      size_title = size_title,
+      base_size = base_size
     )
   } else {
     if (type == "qq") { # nolint
@@ -91,6 +99,7 @@ plot.see_check_normality <- function(x,
           dot_alpha = dot_alpha,
           colors = colors,
           detrend = detrend,
+          base_size = base_size,
           transform = stats::qnorm,
           ...
         ))
@@ -106,6 +115,9 @@ plot.see_check_normality <- function(x,
         dat,
         size_point = size_point,
         size_line = size_line,
+        size_axis_title = size_axis_title,
+        size_title = size_title,
+        base_size = base_size,
         alpha_level = alpha,
         detrend = detrend,
         dot_alpha_level = dot_alpha,
@@ -128,7 +140,14 @@ plot.see_check_normality <- function(x,
         mean(r),
         stats::sd(r)
       )
-      .plot_diag_norm(dat, size_line = size_line)
+      .plot_diag_norm(
+        dat,
+        size_line = size_line,
+        alpha_level = alpha,
+        base_size = base_size,
+        size_axis_title = size_axis_title,
+        size_title = size_title
+      )
     } else if (type == "pp") {
       x <- suppressMessages(sort(stats::residuals(model), na.last = NA))
       dat <- data.frame(res = x)
@@ -136,6 +155,9 @@ plot.see_check_normality <- function(x,
         dat,
         size_point = size_point,
         size_line = size_line,
+        base_size = base_size,
+        size_axis_title = size_axis_title,
+        size_title = size_title,
         alpha_level = alpha,
         detrend = detrend,
         dot_alpha_level = dot_alpha,
@@ -150,8 +172,11 @@ plot.see_check_normality <- function(x,
 
 .plot_diag_norm <- function(x,
                             size_line,
+                            size_axis_title = 10,
+                            size_title = 12,
                             alpha_level = 0.2,
                             theme_style = theme_lucid,
+                            base_size = 10,
                             colors = unname(social_colors(c("green", "blue", "red")))) {
   ggplot2::ggplot(x, ggplot2::aes(x = .data$x)) +
     ggplot2::geom_ribbon(
@@ -174,9 +199,11 @@ plot.see_check_normality <- function(x,
       subtitle = "Distribution should be close to the normal curve"
     ) +
     theme_style(
-      base_size = 10,
+      base_size = base_size,
       plot.title.space = 3,
-      axis.title.space = 5
+      axis.title.space = 5,
+      plot.title.size = size_title,
+      axis.title.size = size_axis_title
     ) +
     ggplot2::scale_y_continuous(labels = NULL)
 }
@@ -187,10 +214,13 @@ plot.see_check_normality <- function(x,
 .plot_diag_qq <- function(x,
                           size_point,
                           size_line,
+                          size_axis_title = 10,
+                          size_title = 12,
                           alpha_level = 0.2,
                           detrend = FALSE,
                           method = "ell",
                           theme_style = theme_lucid,
+                          base_size = 10,
                           colors = unname(social_colors(c("green", "blue", "red"))),
                           dot_alpha_level = 0.8,
                           show_dots = TRUE,
@@ -293,9 +323,11 @@ plot.see_check_normality <- function(x,
       x = "Standard Normal Distribution Quantiles"
     ) +
     theme_style(
-      base_size = 10,
+      base_size = base_size,
       plot.title.space = 3,
-      axis.title.space = 5
+      axis.title.space = 5,
+      plot.title.size = size_title,
+      axis.title.size = size_axis_title
     )
 }
 
@@ -305,10 +337,13 @@ plot.see_check_normality <- function(x,
 .plot_diag_pp <- function(x,
                           size_point,
                           size_line,
+                          size_axis_title = base_size,
+                          size_title = 12,
                           alpha_level = 0.2,
                           detrend = FALSE,
                           method = "ell",
                           theme_style = theme_lucid,
+                          base_size = 10,
                           colors = unname(social_colors(c("green", "blue", "red"))),
                           dot_alpha_level = 0.8) {
   if (requireNamespace("qqplotr", quietly = TRUE)) {
@@ -361,9 +396,11 @@ plot.see_check_normality <- function(x,
       x = "Standard Normal Cumulative Probability"
     ) +
     theme_style(
-      base_size = 10,
+      base_size = base_size,
       plot.title.space = 3,
-      axis.title.space = 5
+      axis.title.space = 5,
+      plot.title.size = size_title,
+      axis.title.size = size_axis_title
     )
 }
 
@@ -373,9 +410,12 @@ plot.see_check_normality <- function(x,
 .plot_diag_reqq <- function(x,
                             size_point,
                             size_line,
+                            size_axis_title = base_size,
+                            size_title = 12,
                             panel = TRUE,
                             alpha_level = 0.2,
                             theme_style = theme_lucid,
+                            base_size = 10,
                             colors = unname(social_colors(c("green", "blue", "red"))),
                             dot_alpha_level = 0.8,
                             show_dots = TRUE) {
@@ -402,9 +442,11 @@ plot.see_check_normality <- function(x,
         alpha = dot_alpha_level
       ) +
       theme_style(
-        base_size = 10,
+        base_size = base_size,
         plot.title.space = 3,
-        axis.title.space = 5
+        axis.title.space = 5,
+        plot.title.size = size_title,
+        axis.title.size = size_axis_title
       )
 
     if (isTRUE(show_dots)) {
