@@ -33,6 +33,9 @@
 plot.see_check_outliers <- function(x,
                                     size_text = 3.5,
                                     size_line = 0.8,
+                                    size_title = 12,
+                                    size_axis_title = base_size,
+                                    base_size = 10,
                                     dot_alpha = 0.8,
                                     colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
                                     rescale_distance = TRUE,
@@ -49,6 +52,9 @@ plot.see_check_outliers <- function(x,
       show_labels = show_labels,
       size_text = size_text,
       size_line = size_line,
+      size_axis_title = size_axis_title,
+      size_title = size_title,
+      base_size = base_size,
       dot_alpha_level = dot_alpha,
       colors = colors
     )
