@@ -1,6 +1,9 @@
 #' @export
 plot.see_check_overdisp <- function(x,
                                     size_line = 0.8,
+                                    size_title = 12,
+                                    size_axis_title = base_size,
+                                    base_size = 10,
                                     colors = c("#3aaf85", "#1b6ca8"),
                                     type = 1,
                                     ...) {
@@ -9,6 +12,9 @@ plot.see_check_overdisp <- function(x,
     style = theme_lucid,
     colors = colors,
     size_line = size_line,
+    size_title = size_title,
+    size_axis_title = size_axis_title,
+    base_size = base_size,
     type = type
   )
 }
@@ -16,6 +22,9 @@ plot.see_check_overdisp <- function(x,
 
 .plot_diag_overdispersion <- function(x,
                                       theme_style = theme_lucid,
+                                      size_axis_title = base_size,
+                                      size_title = 12,
+                                      base_size = 10,
                                       colors = c("#3aaf85", "#1b6ca8"),
                                       size_line = 0.8,
                                       type = 1,
@@ -32,9 +41,11 @@ plot.see_check_overdisp <- function(x,
         y = "Residual variance"
       ) +
       theme_style(
-        base_size = 10,
+        base_size = base_size,
         plot.title.space = 3,
-        axis.title.space = 5
+        axis.title.space = 5,
+        plot.title.size = size_title,
+        axis.title.size = size_axis_title
       )
   } else {
     p <- ggplot2::ggplot(x) +
@@ -52,9 +63,11 @@ plot.see_check_overdisp <- function(x,
         y = "Standardized resiuduals"
       ) +
       theme_style(
-        base_size = 10,
+        base_size = base_size,
         plot.title.space = 3,
-        axis.title.space = 5
+        axis.title.space = 5,
+        plot.title.size = size_title,
+        axis.title.size = size_axis_title
       )
   }
 
